@@ -91,7 +91,7 @@ class DlgChecksumSettingsWidget : public KCModule
     Q_OBJECT
 
 public:
-    explicit DlgChecksumSettingsWidget(QWidget *parent = nullptr, const QVariantList &args = QVariantList());
+    explicit DlgChecksumSettingsWidget(QObject *parent = nullptr, const KPluginMetaData &args = {});
     ~DlgChecksumSettingsWidget() override;
 
 public Q_SLOTS:
